Index: ui/gfx/compositor/layer_animation_manager.h |
diff --git a/ui/gfx/compositor/layer_animator.h b/ui/gfx/compositor/layer_animation_manager.h |
similarity index 84% |
copy from ui/gfx/compositor/layer_animator.h |
copy to ui/gfx/compositor/layer_animation_manager.h |
index 52b8870b66c4ddb43faa696f24652619ac704617..b5b6540c9587ad3555411d9b8ba1cea5675b60fc 100644 |
--- a/ui/gfx/compositor/layer_animator.h |
+++ b/ui/gfx/compositor/layer_animation_manager.h |
@@ -2,8 +2,8 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef UI_GFX_COMPOSITOR_LAYER_ANIMATOR_H_ |
-#define UI_GFX_COMPOSITOR_LAYER_ANIMATOR_H_ |
+#ifndef UI_GFX_COMPOSITOR_LAYER_ANIMATION_MANAGER_H_ |
+#define UI_GFX_COMPOSITOR_LAYER_ANIMATION_MANAGER_H_ |
#pragma once |
#include <map> |
@@ -27,8 +27,8 @@ class Layer; |
class LayerAnimatorDelegate; |
class Transform; |
-// LayerAnimator manages animating various properties of a Layer. |
-class COMPOSITOR_EXPORT LayerAnimator : public ui::AnimationDelegate { |
+// LayerAnimationManager manages animating various properties of a Layer. |
+class COMPOSITOR_EXPORT LayerAnimationManager : public ui::AnimationDelegate { |
public: |
// Types of properties that can be animated. |
enum AnimationProperty { |
@@ -37,10 +37,11 @@ class COMPOSITOR_EXPORT LayerAnimator : public ui::AnimationDelegate { |
TRANSFORM, |
}; |
- explicit LayerAnimator(Layer* layer); |
- virtual ~LayerAnimator(); |
+ explicit LayerAnimationManager(Layer* layer); |
+ virtual ~LayerAnimationManager(); |
- // Sets the animation to use. LayerAnimator takes ownership of the animation. |
+ // Sets the animation to use. LayerAnimationManager takes ownership of the |
+ // animation. |
void SetAnimation(Animation* animation); |
ui::Layer* layer() { return layer_; } |
@@ -120,9 +121,9 @@ class COMPOSITOR_EXPORT LayerAnimator : public ui::AnimationDelegate { |
bool got_initial_tick_; |
- DISALLOW_COPY_AND_ASSIGN(LayerAnimator); |
+ DISALLOW_COPY_AND_ASSIGN(LayerAnimationManager); |
}; |
} // namespace ui |
-#endif // UI_GFX_COMPOSITOR_LAYER_ANIMATOR_H_ |
+#endif // UI_GFX_COMPOSITOR_LAYER_ANIMATION_MANAGER_H_ |